@@ -102,17 +102,29 @@ class cExportItem(gmBusinessDBObject.cBusinessDBObject):
 		# must update XMIN now ...
 		self.refetch_payload()
 		return True
-	#--------------------------------------------------------
-	def export_to_file(self, aChunkSize=0, filename=None, directory=None):
 
+	#--------------------------------------------------------
+	def save_to_file(self, aChunkSize=0, filename=None, directory=None):
+
+		# data linked from archive
 		if self._payload[self._idx['pk_doc_obj']] is not None:
-			return self.document_part.export_to_file (
+			part = self.document_part
+			if filename is None:
+				filename = part.get_useful_filename (
+					make_unique = False,
+					directory = directory,
+					include_gnumed_tag = False,
+					date_before_type = True,
+					name_first = False
+				)
+			return part.save_to_file (
 				aChunkSize = aChunkSize,
 				filename = filename,
-				ignore_conversion_problems = True,
-				directory = directory
+				ignore_conversion_problems = True
+				#, directory = directory
 			)
 
+		# data in export area table
 		if filename is None:
 			filename = self.get_useful_filename(directory = directory)
 
@@ -130,13 +142,14 @@ class cExportItem(gmBusinessDBObject.cBusinessDBObject):
 			return None
 
 		return filename
+
 	#--------------------------------------------------------
 	def display_via_mime(self, chunksize=0, block=None):
 
 		if self._payload[self._idx['pk_doc_obj']] is not None:
 			return self.document_part.display_via_mime(chunksize = chunksize, block = block)
 
-		fname = self.export_to_file(aChunkSize = chunksize)
+		fname = self.save_to_file(aChunkSize = chunksize)
 		if fname is None:
 			return False, ''
 
@@ -145,6 +158,7 @@ class cExportItem(gmBusinessDBObject.cBusinessDBObject):
 			return False, msg
 
 		return True, ''
+
 	#--------------------------------------------------------
 	def get_useful_filename(self, patient=None, directory=None):
 		patient_part = ''
@@ -155,7 +169,7 @@ class cExportItem(gmBusinessDBObject.cBusinessDBObject):
 		suffix = '.dat'
 		if self._payload[self._idx['filename']] is not None:
 			tmp, suffix = os.path.splitext(self._payload[self._idx['filename']])
-			suffix = suffix.strip().replace(' ', '-')
+			suffix = suffix.strip().replace(' ', '-').lower()
 			if suffix == u'':
 				suffix = '.dat'
 
@@ -166,6 +180,7 @@ class cExportItem(gmBusinessDBObject.cBusinessDBObject):
 		)
 
 		return os.path.join(directory, fname)
+
 	#--------------------------------------------------------
 	# properties
 	#--------------------------------------------------------
@@ -313,22 +328,22 @@ _html_end = u"""
 
 
 _autorun_inf = (
-u'[AutoRun]\r\n'						# needs \r\n for Windows
-u'label=%s\r\n'							# patient name/DOB
-u'shellexecute=index.html\r\n'
-u'action=%s\r\n'						# % _('Browse patient data')
-u'\r\n'
-u'[Content]\r\n'
-u'PictureFiles=yes\r\n'
-u'VideoFiles=yes\r\n'
-u'MusicFiles=no\r\n'
-u'\r\n'
-u'[IgnoreContentPaths]\r\n'
-u'\documents\r\n'
-u'\r\n'
-u'[unused]\r\n'
-u'open=requires explicit executable\r\n'
-u'icon=use standard icon for storage unit\r\n'
+	u'[AutoRun]\r\n'						# needs \r\n for Windows
+	u'label=%s\r\n'							# patient name/DOB
+	u'shellexecute=index.html\r\n'
+	u'action=%s\r\n'						# % _('Browse patient data')
+	u'\r\n'
+	u'[Content]\r\n'
+	u'PictureFiles=yes\r\n'
+	u'VideoFiles=yes\r\n'
+	u'MusicFiles=no\r\n'
+	u'\r\n'
+	u'[IgnoreContentPaths]\r\n'
+	u'\documents\r\n'
+	u'\r\n'
+	u'[unused]\r\n'
+	u'open=requires explicit executable\r\n'
+	u'icon=use standard icon for storage unit\r\n'
 )
 
 
@@ -420,6 +435,7 @@ class cExportArea(object):
 
 		delete_export_item(pk_export_item = item['pk_export_item'])
 		return None
+
 	#--------------------------------------------------------
 	def add_files(self, filenames=None, hint=None):
 		all_ok = True
@@ -427,22 +443,41 @@ class cExportArea(object):
 			all_ok = all_ok and (self.add_file(filename = fname, hint = hint) is not None)
 
 		return all_ok
+
 	#--------------------------------------------------------
 	def add_documents(self, documents=None):
 		for doc in documents:
+			doc_tag = _(u'%s (%s)%s') % (
+				doc['l10n_type'],
+				gmDateTime.pydt_strftime(doc['clin_when'], '%Y %b %d'),
+				gmTools.coalesce(doc['comment'], u'', u' "%s"')
+			)
 			for obj in doc.parts:
 				if self.document_part_item_exists(pk_part = obj['pk_obj']):
 					continue
+				f_ext = u''
+				if obj['filename'] is not None:
+					f_ext = os.path.splitext(obj['filename'])[1].strip('.').strip()
+				if f_ext != u'':
+					f_ext = u' .' + f_ext.upper()
+				obj_tag = _(u'part %s (%s%s)%s') % (
+					obj['seq_idx'],
+					gmTools.size2str(obj['size']),
+					f_ext,
+					gmTools.coalesce(obj['obj_comment'], u'', u' "%s"')
+				)
 				create_export_item (
-					description = _('doc: %s') % obj.format_single_line(),
+					description = u'%s - %s' % (doc_tag, obj_tag),
 					pk_doc_obj = obj['pk_obj']
 				)
+
 	#--------------------------------------------------------
 	def document_part_item_exists(self, pk_part=None):
 		cmd = u"SELECT EXISTS (SELECT 1 FROM clin.export_item WHERE fk_doc_obj = %(pk_obj)s)"
 		args = {'pk_obj': pk_part}
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = False)
 		return rows[0][0]
+
 	#--------------------------------------------------------
 	def md5_exists(self, md5=None, include_document_parts=False):
 		where_parts = [
@@ -501,7 +536,7 @@ class cExportArea(object):
 
 		mugshot = pat.document_folder.latest_mugshot
 		if mugshot is not None:
-			_html_start_data['mugshot_url'] = mugshot.export_to_file(directory = doc_dir)
+			_html_start_data['mugshot_url'] = mugshot.save_to_file(directory = doc_dir)
 			_html_start_data['mugshot_alt'] =_('patient photograph from %s') % gmDateTime.pydt_strftime(mugshot['date_generated'], '%B %Y')
 			_html_start_data['mugshot_title'] = gmDateTime.pydt_strftime(mugshot['date_generated'], '%B %Y')
 
@@ -513,9 +548,9 @@ class cExportArea(object):
 		if u'DICOMDIR' in existing_files:
 			_html_start_data[u'browse_dicomdir'] = u'	<li><a href="./DICOMDIR">browse DICOMDIR</a></li>'
 		idx_file.write(_html_start % _html_start_data)
-		# middle
+		# middle (side effect ! -> exports items into files ...)
 		for item in items:
-			item_path = item.export_to_file(directory = doc_dir)
+			item_path = item.save_to_file(directory = doc_dir)
 			item_fname = os.path.split(item_path)[1]
 			idx_file.write(_html_list_item % (
 				item_fname,
@@ -550,13 +585,26 @@ class cExportArea(object):
 		idx_file.write(_html_end % _html_end_data)
 		idx_file.close()
 
+		# start.html (just a copy of index.html, really ;-)
+		start_fname = os.path.join(base_dir, u'start.html')
+		try:
+			shutil.copy2(idx_fname, start_fname)
+		except Exception:
+			_log.exception('cannot copy %s to %s', idx_fname, start_fname)
+
 		# autorun.inf
+		name = pat.active_name
+		last = name['lastnames'][:14]
+		first = name['firstnames'][:min(14, 18 - len(last))]
+		label = ((u'%s%s%s' % (
+			u'%s,%s' % (last, first),
+			gmTools.coalesce(pat['gender'], u'', u' (%s)'),
+			pat.get_formatted_dob(format = ' %Y%m%d', none_string = u'', honor_estimation = False)
+		)).strip())[:32]		# max 32 chars, supposedly ASCII, but LATIN1 works pretty well
+		action = _('Browse patient data')
 		autorun_fname = os.path.join(base_dir, u'autorun.inf')
 		autorun_file = io.open(autorun_fname, mode = u'wt', encoding = u'utf8')
-		autorun_file.write(_autorun_inf % (
-			(pat.get_description_gender(with_nickname = False) + u', ' + _(u'born') + u' ' + pat.get_formatted_dob('%Y %B %d')).strip(),
-			_('Browse patient data')
-		))
+		autorun_file.write(_autorun_inf % (label, action))
 		autorun_file.close()
 
 		# cd.inf
@@ -591,6 +639,7 @@ class cExportArea(object):
 		shutil.move(prax.vcf, os.path.join(base_dir, u'praxis.vcf'))
 
 		return base_dir
+
 	#--------------------------------------------------------
 	# properties
 	#--------------------------------------------------------
