@@ -14,7 +14,7 @@ import sys
 import os
 import os.path
 import fileinput
-import codecs
+import io
 import time
 import glob
 import datetime as pyDT
@@ -165,7 +165,7 @@ class cDTO_CCRdr(gmPerson.cDTO_person):
 			name_candidate_ids = [ o.ID for o in old_idents ]
 			for r in rows:
 				if r[0] not in name_candidate_ids:
-					old_idents.append(gmPerson.cIdentity(aPK_obj = r[0]))
+					old_idents.append(gmPerson.cPerson(aPK_obj = r[0]))
 
 		return old_idents
 
@@ -207,7 +207,7 @@ class cDTO_CCRdr(gmPerson.cDTO_person):
 	def __load_vk_file(self):
 
 		_log.debug('loading eGK/KVK/PKVK data from [%s]', self.filename)
-		vk_file = codecs.open(filename = self.filename, mode = 'rU', encoding = 'utf8')
+		vk_file = io.open(self.filename, mode = 'rt', encoding = 'utf8')
 		self.raw_data = json.load(vk_file)
 		vk_file.close()
 
@@ -393,7 +393,7 @@ select pk_identity from dem.v_external_ids4identity where
 			for oid in old_idents:
 				if r[0] == oid.ID:
 					break
-			new_idents.append(gmPerson.cIdentity(aPK_obj = r['pk_identity']))
+			new_idents.append(gmPerson.cPerson(aPK_obj = r['pk_identity']))
 
 		old_idents.extend(new_idents)
 
@@ -440,7 +440,7 @@ select pk_identity from dem.v_external_ids4identity where
 
 		_log.debug('parsing eGK data in [%s]', self.filename)
 
-		egk_file = codecs.open(filename = self.filename, mode = 'rU', encoding = 'utf8')
+		egk_file = io.open(self.filename, mode = 'rt', encoding = 'utf8')
 
 		card_type_seen = False
 		for line in egk_file:
@@ -530,7 +530,7 @@ select pk_identity from dem.v_external_ids4identity where
 			for oid in old_idents:
 				if r[0] == oid.ID:
 					break
-			new_idents.append(gmPerson.cIdentity(aPK_obj = r['pk_identity']))
+			new_idents.append(gmPerson.cPerson(aPK_obj = r['pk_identity']))
 
 		old_idents.extend(new_idents)
 
@@ -575,7 +575,7 @@ select pk_identity from dem.v_external_ids4identity where
 
 		_log.debug('parsing KVK data in [%s]', self.filename)
 
-		kvk_file = codecs.open(filename = self.filename, mode = 'rU', encoding = 'utf8')
+		kvk_file = io.open(self.filename, mode = 'rt', encoding = 'utf8')
 
 		card_type_seen = False
 		for line in kvk_file:
@@ -624,7 +624,7 @@ select pk_identity from dem.v_external_ids4identity where
 #============================================================
 def detect_card_type(card_file=None):
 
-	data_file = codecs.open(filename = card_file, mode = 'rU', encoding = 'utf8')
+	data_file = io.open(card_file, mode = 'rt', encoding = 'utf8')
 
 	for line in kvk_file:
 		line = line.replace('\n', '').replace('\r', '')
