@@ -49,7 +49,6 @@ class cStaff(gmBusinessDBObject.cBusinessDBObject):
 	def __init__(self, aPK_obj=None, row=None):
 		# by default get staff corresponding to CURRENT_USER
 		if (aPK_obj is None) and (row is None):
-			#cmd = u"select *, _(role) AS l10n_role from dem.v_staff where "
 			cmd = _SQL_fetch_staff_fields % u"db_user = CURRENT_USER"
 			try:
 				rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd}], get_col_idx=True)
@@ -110,8 +109,8 @@ class cStaff(gmBusinessDBObject.cBusinessDBObject):
 	inbox = property(_get_inbox, _set_inbox)
 	#--------------------------------------------------------
 	def _get_identity(self):
-		from Gnumed.business import gmPerson
-		return gmPerson.cIdentity(aPK_obj = self._payload[self._idx['pk_identity']])
+		from Gnumed.business.gmPerson import cPerson
+		return cPerson(self._payload[self._idx['pk_identity']])
 
 	identity = property(_get_identity, lambda x:x)
 	#--------------------------------------------------------
@@ -137,6 +136,7 @@ class cStaff(gmBusinessDBObject.cBusinessDBObject):
 		return True
 
 	role = property(lambda x:x, set_role)
+
 #============================================================
 def get_staff_list(active_only=False):
 	if active_only:
@@ -153,6 +153,7 @@ def get_staff_list(active_only=False):
 		}
 		staff_list.append(cStaff(row=obj_row))
 	return staff_list
+
 #------------------------------------------------------------
 def create_staff(conn=None, db_account=None, password=None, identity=None, short_alias=None):
 	args = {
@@ -191,6 +192,7 @@ def create_staff(conn=None, db_account=None, password=None, identity=None, short
 		raise
 
 	return True, None
+
 #------------------------------------------------------------
 def delete_staff(conn=None, pk_staff=None):
 	queries = [{'cmd': u'DELETE FROM dem.staff WHERE pk = %(pk)s', 'args': {'pk': pk_staff}}]
@@ -209,6 +211,7 @@ def delete_staff(conn=None, pk_staff=None):
 		raise
 
 	return True, None
+
 #------------------------------------------------------------
 def activate_staff(conn=None, pk_staff=None):
 	# 1) activate staff entry
@@ -225,6 +228,7 @@ def activate_staff(conn=None, pk_staff=None):
 	)
 
 	return True
+
 #------------------------------------------------------------
 def deactivate_staff(conn=None, pk_staff=None):
 
@@ -241,9 +245,11 @@ def deactivate_staff(conn=None, pk_staff=None):
 	)
 
 	return True
+
 #============================================================
 def set_current_provider_to_logged_on_user():
 	gmCurrentProvider(provider = cStaff())
+
 #============================================================
 class gmCurrentProvider(gmBorg.cBorg):
 	"""Staff member Borg to hold currently logged on provider.
@@ -271,15 +277,15 @@ class gmCurrentProvider(gmBorg.cBorg):
 		if not isinstance(provider, cStaff):
 			raise ValueError, 'cannot set logged on provider to [%s], must be either None or cStaff instance' % str(provider)
 
-		# same ID, no change needed
-		if self.provider['pk_staff'] == provider['pk_staff']:
-			return None
-
 		# first invocation
 		if isinstance(self.provider, gmNull.cNull):
 			self.provider = provider
 			return None
 
+		# same ID, no change needed
+		if self.provider['pk_staff'] == provider['pk_staff']:
+			return None
+
 		# user wants different provider
 		raise ValueError, 'provider change [%s] -> [%s] not yet supported' % (self.provider['pk_staff'], provider['pk_staff'])
 
@@ -302,6 +308,7 @@ class gmCurrentProvider(gmBorg.cBorg):
 		if not isinstance(self.provider, gmNull.cNull):
 			return getattr(self.provider, attribute)
 #		raise AttributeError
+
 #============================================================
 # main/testing
 #============================================================
