@@ -1,7 +1,6 @@
 """GNUmed vaccination related business objects.
 """
 #============================================================
-__version__ = "$Revision: 1.38 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -15,7 +14,6 @@ from Gnumed.business import gmMedication
 
 
 _log = logging.getLogger('gm.vaccination')
-_log.info(__version__)
 
 #============================================================
 def get_indications(order_by=None, pk_indications=None):
@@ -33,6 +31,7 @@ def get_indications(order_by=None, pk_indications=None):
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = False)
 
 	return rows
+
 #============================================================
 _sql_fetch_vaccine = u"""SELECT *, xmin_vaccine FROM clin.v_vaccines WHERE %s"""
 
@@ -128,6 +127,7 @@ class cVaccine(gmBusinessDBObject.cBusinessDBObject):
 		return rows[0][0]
 
 	is_in_use = property(_get_is_in_use, lambda x:x)
+
 #------------------------------------------------------------
 def create_vaccine(pk_brand=None, brand_name=None, indications=None, pk_indications=None):
 
@@ -229,6 +229,7 @@ def regenerate_generic_vaccines():
 	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd}], return_data = True)
 
 	return rows[0][0]
+
 #============================================================
 # vaccination related classes
 #============================================================
@@ -271,6 +272,16 @@ class cVaccination(gmBusinessDBObject.cBusinessDBObject):
 		u'pk_encounter',
 		u'pk_episode'
 	]
+
+	#--------------------------------------------------------
+	def format_maximum_information(self, patient=None):
+		return self.format (
+			with_indications = True,
+			with_comment = True,
+			with_reaction = True,
+			date_format = '%Y %b %d'
+		)
+
 	#--------------------------------------------------------
 	def format(self, with_indications=False, with_comment=False, with_reaction=False, date_format='%Y-%m-%d'):
 
@@ -295,11 +306,13 @@ class cVaccination(gmBusinessDBObject.cBusinessDBObject):
 			lines.append(u'   %s' % u' / '.join(self._payload[self._idx['indications']]))
 
 		return lines
+
 	#--------------------------------------------------------
 	def _get_vaccine(self):
 		return cVaccine(aPK_obj = self._payload[self._idx['pk_vaccine']])
 
 	vaccine = property(_get_vaccine, lambda x:x)
+
 #------------------------------------------------------------
 def create_vaccination(encounter=None, episode=None, vaccine=None, batch_no=None):
 
