@@ -1,4 +1,7 @@
-"""GNUmed database object business class.
+
+from __future__ import print_function
+
+__doc__ = """GNUmed database object business class.
 
 Overview
 --------
@@ -81,10 +84,10 @@ episode, encounter).
 
 One can offer all the data to the user:
 
-self.original_payload
+self.payload_most_recently_fetched
 - contains the data at the last successful refetch
 
-self.modified_payload
+self.payload_most_recently_attempted_to_store
 - contains the modified payload just before the last
   failure of save_payload() - IOW what is currently
   in the database
@@ -141,7 +144,11 @@ if __name__ == '__main__':
 from Gnumed.pycommon import gmExceptions
 from Gnumed.pycommon import gmPG2
 from Gnumed.pycommon.gmDateTime import pydt_strftime
-from Gnumed.pycommon.gmTools import tex_escape_string, xetex_escape_string
+from Gnumed.pycommon.gmTools import tex_escape_string
+from Gnumed.pycommon.gmTools import xetex_escape_string
+from Gnumed.pycommon.gmTools import compare_dict_likes
+from Gnumed.pycommon.gmTools import format_dict_like
+from Gnumed.pycommon.gmTools import format_dict_likes_comparison
 
 
 _log = logging.getLogger('gm.db')
@@ -332,9 +339,9 @@ def delete_xxx(pk_XXX=None):
 		self.pk_obj = aPK_obj
 		result = self.refetch_payload(link_obj = link_obj)
 		if result is True:
-			self.original_payload = {}
+			self.payload_most_recently_fetched = {}
 			for field in self._idx.keys():
-				self.original_payload[field] = self._payload[self._idx[field]]
+				self.payload_most_recently_fetched[field] = self._payload[self._idx[field]]
 			return True
 
 		if result is False:
@@ -349,7 +356,7 @@ def delete_xxx(pk_XXX=None):
 			- data: the field values in a list (as returned by
 			  cursor.fetchone() in the DB-API)
 
-		row = {'data': row, 'idx': idx, 'pk_field': 'the PK column name'}
+		row = {'data': rows[0], 'idx': idx, 'pk_field': 'pk_XXX (the PK column name)'}
 
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = True)
 		objects = [ cChildClass(row = {'data': r, 'idx': idx, 'pk_field': 'the PK column name'}) for r in rows ]
@@ -367,15 +374,15 @@ def delete_xxx(pk_XXX=None):
 			_log.critical('faulty <row> argument structure: %s' % row)
 			raise gmExceptions.ConstructorError, "[%s:??]: error loading instance from row data" % self.__class__.__name__
 
-		self.original_payload = {}
+		self.payload_most_recently_fetched = {}
 		for field in self._idx.keys():
-			self.original_payload[field] = self._payload[self._idx[field]]
+			self.payload_most_recently_fetched[field] = self._payload[self._idx[field]]
 	#--------------------------------------------------------
 	def __del__(self):
-		if self.__dict__.has_key('_is_modified'):
+		if u'_is_modified' in self.__dict__:
 			if self._is_modified:
 				_log.critical('[%s:%s]: loosing payload changes' % (self.__class__.__name__, self.pk_obj))
-				_log.debug('original: %s' % self.original_payload)
+				_log.debug('most recently fetched: %s' % self.payload_most_recently_fetched)
 				_log.debug('modified: %s' % self._payload)
 	#--------------------------------------------------------
 	def __str__(self):
@@ -390,6 +397,7 @@ def delete_xxx(pk_XXX=None):
 			#return '[%s:%s]:\n %s' % (self.__class__.__name__, self.pk_obj, '\n '.join(lines))
 		except:
 			return 'nascent [%s @ %s], cannot show payload and primary key' %(self.__class__.__name__, id(self))
+
 	#--------------------------------------------------------
 	def __unicode__(self):
 		lines = []
@@ -402,6 +410,7 @@ def delete_xxx(pk_XXX=None):
 			return '[%s:%s]:\n%s' % (self.__class__.__name__, self.pk_obj, u'\n'.join(lines))
 		except:
 			return 'nascent [%s @ %s], cannot show payload and primary key' %(self.__class__.__name__, id(self))
+
 	#--------------------------------------------------------
 	def __getitem__(self, attribute):
 		# use try: except: as it is faster and we want this as fast as possible
@@ -471,19 +480,22 @@ def delete_xxx(pk_XXX=None):
 	#--------------------------------------------------------
 	def is_modified(self):
 		return self._is_modified
+
 	#--------------------------------------------------------
 	def get_fields(self):
 		try:
 			return self._idx.keys()
 		except AttributeError:
 			return 'nascent [%s @ %s], cannot return keys' %(self.__class__.__name__, id(self))
+
 	#--------------------------------------------------------
 	def get_updatable_fields(self):
 		return self.__class__._updatable_fields
+
 	#--------------------------------------------------------
 	def fields_as_dict(self, date_format='%Y %b %d  %H:%M', none_string=u'', escape_style=None, bool_strings=None):
 		if bool_strings is None:
-			bools = {True: u'true', False: u'false'}
+			bools = {True: u'True', False: u'False'}
 		else:
 			bools = {True: bool_strings[0], False: bool_strings[1]}
 		data = {}
@@ -501,6 +513,9 @@ def delete_xxx(pk_XXX=None):
 				continue
 
 			if isinstance(val, datetime.datetime):
+				if date_format is None:
+					data[field] = val
+					continue
 				data[field] = pydt_strftime(val, format = date_format, encoding = 'utf8')
 				if escape_style in [u'latex', u'tex']:
 					data[field] = tex_escape_string(data[field])
@@ -526,18 +541,58 @@ def delete_xxx(pk_XXX=None):
 	def get_patient(self):
 		_log.error('[%s:%s]: forgot to override get_patient()' % (self.__class__.__name__, self.pk_obj))
 		return None
+
 	#--------------------------------------------------------
-	def format(self):
-		return u'%s' % self
+	def format(self, *args, **kwargs):
+		return format_dict_like (
+			self.fields_as_dict(none_string = u'<?>'),
+			tabular = True,
+			value_delimiters = None
+		).split(u'\n')
+
+	#--------------------------------------------------------
+	def _get_revision_history(self, query, args, title):
+		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': query, 'args': args}], get_col_idx = True)
+		lines = []
+		lines.append(u'%s (%s versions)' % (title, rows[0]['row_version'] + 1))
+		if len(rows) == 1:
+			lines.append(u'')
+			lines.extend(format_dict_like (
+					rows[0],
+					left_margin = 1,
+					tabular = True,
+					value_delimiters = None,
+					eol = None
+			))
+			return lines
+
+		for row_idx in range(len(rows)-1):
+			lines.append(u'')
+			row_older = rows[row_idx + 1]
+			row_newer = rows[row_idx]
+			lines.extend(format_dict_likes_comparison (
+				row_older,
+				row_newer,
+				title_left = _('Revision #%s') % row_older['row_version'],
+				title_right = _('Revision #%s') % row_newer['row_version'],
+				left_margin = 0,
+				key_delim = u' | ',
+				data_delim = u' | ',
+				missing_string = u'',
+				ignore_diff_in_keys = ['audit__action_applied', 'audit__action_when', 'audit__action_by', 'pk_audit', 'row_version', 'modified_when', 'modified_by']
+			))
+		return lines
+
 	#--------------------------------------------------------
 	def refetch_payload(self, ignore_changes=False, link_obj=None):
 		"""Fetch field values from backend.
 		"""
 		if self._is_modified:
+			compare_dict_likes(self.original_payload, self.fields_as_dict(date_format = None, none_string = None), u'original payload', u'modified payload')
 			if ignore_changes:
 				_log.critical('[%s:%s]: loosing payload changes' % (self.__class__.__name__, self.pk_obj))
-				_log.debug('original: %s' % self.original_payload)
-				_log.debug('modified: %s' % self._payload)
+				#_log.debug('most recently fetched: %s' % self.payload_most_recently_fetched)
+				#_log.debug('modified: %s' % self._payload)
 			else:
 				_log.critical('[%s:%s]: cannot reload, payload changed' % (self.__class__.__name__, self.pk_obj))
 				return False
@@ -579,7 +634,7 @@ def delete_xxx(pk_XXX=None):
 		args = {}
 		for field in self._idx.keys():
 			args[field] = self._payload[self._idx[field]]
-		self.modified_payload = args
+		self.payload_most_recently_attempted_to_store = args
 
 		close_conn = self.__noop
 		if conn is None:
@@ -604,10 +659,11 @@ def delete_xxx(pk_XXX=None):
 		if len(rows) == 0:
 			return (False, (u'cannot update row', _('[%s:%s]: row not updated (nothing returned), row in use ?') % (self.__class__.__name__, self.pk_obj)))
 
-		# update cached values from should-be-first-and-only result
-		# row of last query,
+		# update cached values from should-be-first-and-only
+		# result row of last query,
 		# update all fields returned such that computed
-		# columns see their new values
+		# columns see their new values (given they are
+		# returned by the query)
 		row = rows[0]
 		for key in idx:
 			try:
@@ -621,14 +677,18 @@ def delete_xxx(pk_XXX=None):
 				_log.error(args)
 				raise
 
+		# only at conn.commit() time will data actually
+		# get committed (and thusly trigger based notifications
+		# be sent out), so reset the local modification flag
+		# right before that
+		self._is_modified = False
 		conn.commit()
 		close_conn()
 
-		self._is_modified = False
 		# update to new "original" payload
-		self.original_payload = {}
+		self.payload_most_recently_fetched = {}
 		for field in self._idx.keys():
-			self.original_payload[field] = self._payload[self._idx[field]]
+			self.payload_most_recently_fetched[field] = self._payload[self._idx[field]]
 
 		return (True, None)
 
@@ -687,12 +747,12 @@ def jsonclasshintify(obj):
 		for k in obj.get_fields():
 			t = jsonclasshintify(obj[k])
 			res[k] = t
-		print "props", res, dir(obj)
+		print("props", res, dir(obj))
 		for attribute in dir(obj):
 			if not attribute.startswith("get_"):
 				continue
 			k = attribute[4:]
-			if res.has_key(k):
+			if k in res:
 				continue
 			getter = getattr(obj, attribute, None)
 			if callable(getter):
@@ -731,9 +791,10 @@ if __name__ == '__main__':
 		'data': [-1, 'bogus_data', datetime.datetime.now()]
 	}
 	obj = cTestObj(row=data)
-	#print obj['wrong_field']
-	#print jsonclasshintify(obj)
+	#print(obj['wrong_field'])
+	#print(jsonclasshintify(obj))
 	#obj['wrong_field'] = 1
-	print obj.fields_as_dict()
+	#print(obj.fields_as_dict())
+	print(obj.format())
 
 #============================================================
