@@ -1549,6 +1549,10 @@ def capture_conn_state(conn=None):
 	conn_status = u'%s (%s)' % (conn.status, map_psyco_conn_status2str[conn.status])
 	if conn.closed != 0:
 		conn_status = u'undefined (%s)' % conn_status
+	try:
+		conn_deferrable = conn.deferrable
+	except AttributeError:
+		conn_deferrable = u'unavailable'
 
 	d = {
 		u'identity': id(conn),
@@ -1560,7 +1564,7 @@ def capture_conn_state(conn=None):
 		u'autocommit': conn.autocommit,
 		u'isolation level (psyco)': isolation_level,
 		u'async': conn.async,
-		u'deferrable': conn.deferrable,
+		u'deferrable': conn_deferrable,
 		u'transaction status': u'%s (%s)' % (tx_status, map_psyco_tx_status2str[tx_status]),
 		u'connection status': conn_status,
 		u'executing async op': conn.isexecuting(),
@@ -1597,6 +1601,10 @@ def capture_cursor_state(cursor=None):
 		isolation_level = u'tx aborted or unknown, cannot retrieve'
 	else:
 		isolation_level = conn.isolation_level
+	try:
+		conn_deferrable = conn.deferrable
+	except AttributeError:
+		conn_deferrable = u'unavailable'
 
 	if cursor.query is None:
 		query = u'<no query>'
@@ -1638,7 +1646,7 @@ Query
 		isolation_level,
 		conn.encoding,
 		conn.async,
-		conn.deferrable,
+		conn_deferrable,
 		conn.readonly,
 		map_psyco_tx_status2str[tx_status],
 		map_psyco_conn_status2str[conn.status],
@@ -1853,7 +1861,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 			if verbose:
 				_log.debug(capture_cursor_state(curs))
 			for notice in notices_accessor.notices:
-				_log.debug(notice.strip(u'\n').strip(u'\r'))
+				_log.debug(unicode(notice, 'utf8', 'replace').strip(u'\n').strip(u'\r'))
 			del notices_accessor.notices[:]
 		# DB related exceptions
 		except dbapi.Error as pg_exc:
@@ -1868,7 +1876,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 						continue
 					_log.error(u'PG diags %s: %s', prop, val)
 			for notice in notices_accessor.notices:
-				_log.error(notice.strip(u'\n').strip(u'\r'))
+				_log.error(unicode(notice, 'utf8', 'replace').strip(u'\n').strip(u'\r'))
 			del notices_accessor.notices[:]
 			pg_exc = make_pg_exception_fields_unicode(pg_exc)
 			_log.error(u'PG error code: %s', pg_exc.pgcode)
@@ -1912,7 +1920,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 			_log.exception('error running query in RW connection')
 			_log.error(capture_cursor_state(curs))
 			for notice in notices_accessor.notices:
-				_log.debug(notice.strip(u'\n').strip(u'\r'))
+				_log.debug(unicode(notice, 'utf8', 'replace').strip(u'\n').strip(u'\r'))
 			del notices_accessor.notices[:]
 			gmLog2.log_stack_trace()
 			try:
@@ -2289,30 +2297,30 @@ def sanity_check_database_settings():
 
 	options2check = {
 		# setting: [expected value, risk, fatal?]
-		u'allow_system_table_mods': [u'off', u'system breakage', False],
-		u'check_function_bodies': [u'on', u'suboptimal error detection', False],
-		u'datestyle': [u'ISO', u'faulty timestamp parsing', True],
-		u'default_transaction_isolation': [u'read committed', u'faulty database reads', True],
-		u'default_transaction_read_only': [u'on', u'accidental database writes', False],
-		u'fsync': [u'on', u'data loss/corruption', True],
-		u'full_page_writes': [u'on', u'data loss/corruption', False],
-		u'lc_messages': [u'C', u'suboptimal error detection', False],
-		u'password_encryption': [u'on', u'breach of confidentiality', False],
-		#u'regex_flavor': [u'advanced', u'query breakage', False],					# 9.0 doesn't support this anymore, default now advanced anyway
-		u'synchronous_commit': [u'on', u'data loss/corruption', False],
-		u'sql_inheritance': [u'on', u'query breakage, data loss/corruption', True],
-		u'ignore_checksum_failure': [u'off', u'data loss/corruption', False],		# starting with PG 9.3
-		u'track_commit_timestamp': [u'on', u'suboptimal auditing', False]			# starting with PG 9.3
+		u'allow_system_table_mods': [[u'off'], u'system breakage', False],
+		u'check_function_bodies': [[u'on'], u'suboptimal error detection', False],
+		u'datestyle': [[u'ISO'], u'faulty timestamp parsing', True],
+		u'default_transaction_isolation': [[u'read committed'], u'faulty database reads', True],
+		u'default_transaction_read_only': [[u'on'], u'accidental database writes', False],
+		u'fsync': [[u'on'], u'data loss/corruption', True],
+		u'full_page_writes': [[u'on'], u'data loss/corruption', False],
+		u'lc_messages': [[u'C'], u'suboptimal error detection', False],
+		u'password_encryption': [[u'on', u'md5', u'scram-sha-256'], u'breach of confidentiality', False],
+		#u'regex_flavor': [[u'advanced'], u'query breakage', False],					# 9.0 doesn't support this anymore, default now advanced anyway
+		u'synchronous_commit': [[u'on'], u'data loss/corruption', False],
+		u'sql_inheritance': [[u'on'], u'query breakage, data loss/corruption', True],	# IF returned (<PG10): better be ON, if NOT returned (PG10): hardwired
+		u'ignore_checksum_failure': [[u'off'], u'data loss/corruption', False],		# starting with PG 9.3
+		u'track_commit_timestamp': [[u'on'], u'suboptimal auditing', False]			# starting with PG 9.3
 	}
 
 	from Gnumed.pycommon import gmCfg2
 	_cfg = gmCfg2.gmCfgData()
 	if _cfg.get(option = u'hipaa'):
-		options2check[u'log_connections'] = [u'on', u'non-compliance with HIPAA', True]
-		options2check[u'log_disconnections'] = [u'on', u'non-compliance with HIPAA', True]
+		options2check[u'log_connections'] = [[u'on'], u'non-compliance with HIPAA', True]
+		options2check[u'log_disconnections'] = [[u'on'], u'non-compliance with HIPAA', True]
 	else:
-		options2check[u'log_connections'] = [u'on', u'non-compliance with HIPAA', None]
-		options2check[u'log_disconnections'] = [u'on', u'non-compliance with HIPAA', None]
+		options2check[u'log_connections'] = [[u'on'], u'non-compliance with HIPAA', None]
+		options2check[u'log_disconnections'] = [[u'on'], u'non-compliance with HIPAA', None]
 
 	cmd = u"SELECT name, setting from pg_settings where name in %(settings)s"
 	rows, idx = run_ro_queries (
@@ -2327,10 +2335,10 @@ def sanity_check_database_settings():
 	for row in rows:
 		option = row['name']
 		value_found = row['setting']
-		value_expected = options2check[option][0]
+		values_expected = options2check[option][0]
 		risk = options2check[option][1]
 		fatal_setting = options2check[option][2]
-		if value_found != value_expected:
+		if value_found not in values_expected:
 			if fatal_setting is True:
 				found_error = True
 			elif fatal_setting is False:
@@ -2342,7 +2350,7 @@ def sanity_check_database_settings():
 				raise ValueError(u'invalid database configuration sanity check')
 			msg.append(_(' option [%s]: %s') % (option, value_found))
 			msg.append(_('  risk: %s') % risk)
-			_log.warning('PG option [%s] set to [%s], expected [%s], risk: <%s>' % (option, value_found, value_expected, risk))
+			_log.warning('PG option [%s] set to [%s], expected %s, risk: <%s>' % (option, value_found, values_expected, risk))
 
 	if found_error:
 		return 2, u'\n'.join(msg)
@@ -2491,27 +2499,6 @@ class cAdapterPyDateTime(object):
 	def getquoted(self):
 		return _timestamp_template % self.__dt.isoformat()
 
-## remove for 0.9
-## ----------------------------------------------------------------------
-##class cAdapterMxDateTime(object):
-##
-##	def __init__(self, dt):
-##		if dt.tz == '???':
-##			_log.info('[%s]: no time zone string available in (%s), assuming local time zone', self.__class__.__name__, dt)
-##		self.__dt = dt
-##
-##	def getquoted(self):
-##		# under some locale settings the mx.DateTime ISO formatter
-##		# will insert "," into the ISO string,
-##		# while this is allowed per the ISO8601 spec PostgreSQL
-##		# cannot currently handle that,
-##		# so map those "," to "." to make things work:
-##		return mxDT.ISO.str(self.__dt).replace(',', '.')
-##
-## ----------------------------------------------------------------------
-## PostgreSQL -> Python
-## ----------------------------------------------------------------------
-
 #=======================================================================
 #  main
 #-----------------------------------------------------------------------
