@@ -1,6 +1,9 @@
 #==================================================
 # GNUmed SANE/TWAIN scanner classes
 #==================================================
+
+from __future__ import print_function
+
 __license__ = "GPL v2 or later"
 __author__ = """Sebastian Hilbert <Sebastian.Hilbert@gmx.net>, Karsten Hilbert <Karsten.Hilbert@gmx.net>"""
 
@@ -11,7 +14,7 @@ import os.path
 import os
 import time
 import shutil
-import codecs
+import io
 import glob
 import logging
 #import stat
@@ -413,8 +416,8 @@ class cXSaneScanner:
 
 		# our closest bet, might contain umlauts
 		enc = gmI18N.get_encoding()
-		fread = codecs.open(self._gm_custom_xsanerc, mode = "rU", encoding = enc)
-		fwrite = codecs.open(session_xsanerc, mode = "w", encoding = enc)
+		fread = io.open(self._gm_custom_xsanerc, mode = "rt", encoding = enc)
+		fwrite = io.open(session_xsanerc, mode = "wt", encoding = enc)
 
 		paths = gmTools.gmPaths()
 		val_dict = {
@@ -499,8 +502,8 @@ if __name__ == '__main__':
 
 		logging.basicConfig(level=logging.DEBUG)
 
-		print "devices:"
-		print get_devices()
+		print("devices:")
+		print(get_devices())
 
 		sys.exit()
 
@@ -512,10 +515,10 @@ if __name__ == '__main__':
 
 		idx = 1
 		for setup in setups:
-			print "scanning page #%s from device [%s]" % (idx, setup['dev'])
+			print("scanning page #%s from device [%s]" % (idx, setup['dev']))
 			idx += 1
 			fnames = acquire_pages_into_files(device = setup['dev'], filename = setup['file'], delay = (idx*5))
 			if fnames is False:
-				print "error, cannot acquire page"
+				print("error, cannot acquire page")
 			else:
-				print " image files:", fnames
+				print(" image files:", fnames)
