@@ -67,7 +67,7 @@ class MemoryDB(Observable):
         self.readonly = True
         
     def supported_event_data(self):
-        return ["description", "icon", "alert", "hyperlink"]
+        return ["description", "icon", "alert", "hyperlink", "progress"]
 
     def search(self, search_string):
         return generic_event_search(self.events, search_string)
@@ -244,7 +244,7 @@ class MemoryDB(Observable):
             self.displayed_period = view_properties.displayed_period
         self.hidden_categories = []
         for cat in self.categories:
-            if not view_properties.category_visible(cat):
+            if not view_properties.is_category_visible(cat):
                 self.hidden_categories.append(cat)
         self._save_if_not_disabled()
 
