@@ -41,6 +41,7 @@ from timelinelib.db.objects import TimePeriod
 from timelinelib.db.utils import safe_write, create_non_exising_path
 from timelinelib.meta.version import get_version
 from timelinelib.time.gregoriantime import GregorianTimeType
+from timelinelib.time.numtime import NumTimeType
 from timelinelib.utils import ex_msg
 from timelinelib.xml.parser import ANY
 from timelinelib.xml.parser import OPTIONAL
@@ -79,14 +80,19 @@ class ParseException(Exception):
 
 class XmlTimeline(MemoryDB):
 
-    def __init__(self, path, load=True, import_timeline=False):
+    def __init__(self, path, load=True, import_timeline=False, timetype=None):
         MemoryDB.__init__(self)
         self.path = path
-        self.time_type = GregorianTimeType()
+        self.time_type = self._select_timetype(timetype)
         if load == True:
             self._load()
             self._fill_containers()
 
+    def _select_timetype(self, timetype):
+        if timetype == None:
+            timetype = GregorianTimeType()
+        return timetype
+    
     def _parse_time(self, time_string):
         return self.get_time_type().parse_time(time_string)
 
@@ -177,6 +183,7 @@ class XmlTimeline(MemoryDB):
         on the version.
         """
         tmp_dict["partial_schema"].add_child_tags([
+            Tag("timetype", OPTIONAL, self._parse_timetype),
             Tag("categories", SINGLE, None, [
                 Tag("category", ANY, self._parse_category, [
                     Tag("name", SINGLE, parse_fn_store("tmp_name")),
@@ -190,6 +197,7 @@ class XmlTimeline(MemoryDB):
                     Tag("start", SINGLE, parse_fn_store("tmp_start")),
                     Tag("end", SINGLE, parse_fn_store("tmp_end")),
                     Tag("text", SINGLE, parse_fn_store("tmp_text")),
+                    Tag("progress", OPTIONAL, parse_fn_store("tmp_progress")),
                     Tag("fuzzy", OPTIONAL, parse_fn_store("tmp_fuzzy")),
                     Tag("locked", OPTIONAL, parse_fn_store("tmp_locked")),
                     Tag("ends_today", OPTIONAL, parse_fn_store("tmp_ends_today")),
@@ -218,6 +226,16 @@ class XmlTimeline(MemoryDB):
             ]),
         ])
 
+    def _parse_timetype(self, text, tmp_dict):
+        self.time_type = None
+        valid_time_types = (GregorianTimeType(), NumTimeType())
+        for timetype in valid_time_types:
+            if text == timetype.get_name():
+                self.time_type = timetype
+                break
+        if self.time_type is None:
+            raise ParseException("Invalid timetype '%s' found." % text)
+    
     def _parse_category(self, text, tmp_dict):
         name = tmp_dict.pop("tmp_name")
         color = parse_color(tmp_dict.pop("tmp_color"))
@@ -241,6 +259,7 @@ class XmlTimeline(MemoryDB):
         start = self._parse_time(tmp_dict.pop("tmp_start"))
         end = self._parse_time(tmp_dict.pop("tmp_end"))
         text = tmp_dict.pop("tmp_text")
+        progress = self._parse_optional_int(tmp_dict, "tmp_progress")
         fuzzy = self._parse_optional_bool(tmp_dict, "tmp_fuzzy")
         locked = self._parse_optional_bool(tmp_dict, "tmp_locked")
         ends_today = self._parse_optional_bool(tmp_dict, "tmp_ends_today")
@@ -274,6 +293,7 @@ class XmlTimeline(MemoryDB):
         event.set_data("icon", icon)
         event.set_data("alert", alert)
         event.set_data("hyperlink", hyperlink)
+        event.set_data("progress", int(progress))
         self.save_event(event)
 
     def _text_starts_with_added_space(self, text):
@@ -328,6 +348,12 @@ class XmlTimeline(MemoryDB):
         else:
             return False
 
+    def _parse_optional_int(self, tmp_dict, id):
+        if tmp_dict.has_key(id):
+            return int(tmp_dict.pop(id))
+        else:
+            return 0
+
     def _parse_optional_color(self, tmp_dict, id):
         if tmp_dict.has_key(id):
             return parse_color(tmp_dict.pop(id))
@@ -364,6 +390,7 @@ class XmlTimeline(MemoryDB):
 
     def _write_timeline(self, file):
         write_simple_tag(file, "version", get_version(), INDENT1)
+        write_simple_tag(file, "timetype", self.time_type.get_name(), INDENT1)
         self._write_categories(file)
         self._write_events(file)
         self._write_view(file)
@@ -405,14 +432,15 @@ class XmlTimeline(MemoryDB):
             if self._text_starts_with_container_tag(evt.text):
                 text = self._add_leading_space_to_text(evt.text)
             write_simple_tag(file, "text", text, INDENT3)
+        if evt.get_data("progress") is not None:
+            write_simple_tag(file, "progress", "%s" % evt.get_data("progress"), INDENT3)
         write_simple_tag(file, "fuzzy", "%s" % evt.fuzzy, INDENT3)
         write_simple_tag(file, "locked", "%s" % evt.locked, INDENT3)
         write_simple_tag(file, "ends_today", "%s" % evt.ends_today, INDENT3)
         if evt.category is not None:
             write_simple_tag(file, "category", evt.category.name, INDENT3)
         if evt.get_data("description") is not None:
-            write_simple_tag(file, "description", evt.get_data("description"),
-                             INDENT3)
+            write_simple_tag(file, "description", evt.get_data("description"), INDENT3)
         alert = evt.get_data("alert")
         if alert is not None:
             write_simple_tag(file, "alert", self.alert_string(alert),
