@@ -18,7 +18,13 @@
 
 def generic_event_search(events, search_string):
     def match(event):
-        return search_string.lower() in event.text.lower()
+        target = search_string.lower()
+        description = event.get_data("description")
+        if description is None:
+            description = ""
+        else:
+            description = description.lower()
+        return target in event.text.lower() or target in description
     def mean_time(event):
         return event.mean_time()
     matches = [event for event in events if match(event)]
