@@ -35,10 +35,11 @@ class CategoriesEditor(wx.Dialog):
     """
 
     def __init__(self, parent, timeline):
-        wx.Dialog.__init__(self, parent, title=_("Edit Categories"))
+        wx.Dialog.__init__(self, parent, title=_("Edit Categories"), name="categories_editor", 
+                           style=wx.DEFAULT_DIALOG_STYLE|wx.RESIZE_BORDER)
         self.db = timeline
-        self.cat_tree = self._create_gui()
-        self._fill_controls_with_data()
+        self._create_gui()
+        self._bind()
 
     def ok_to_edit(self):
         """
@@ -56,46 +57,57 @@ class CategoriesEditor(wx.Dialog):
         when we close the CategoriesEditor, so we do nothing.
         """
     
-    def _fill_controls_with_data(self):
+    def _create_gui(self):
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        sizer.Add(self._create_cat_tree(), flag=wx.ALL|wx.EXPAND, border=BORDER, proportion=1)
+        sizer.Add(self._create_buttons(), flag=wx.ALL|wx.EXPAND, border=BORDER)
+        self.SetSizerAndFit(sizer)
         self.cat_tree.initialize_from_db(self.db)
 
-    def _create_gui(self):
-        vbox = wx.BoxSizer(wx.VERTICAL)
-        cat_tree = self._create_cat_tree(vbox)
-        self._create_buttons(vbox)
-        self.SetSizerAndFit(vbox)
+    def _bind(self):
         self.Bind(wx.EVT_CLOSE, self._window_on_close)
-        return cat_tree
+        self.Bind(wx.EVT_SIZE, self._on_size, self)
+        self.Bind(wx.EVT_TREE_SEL_CHANGED, self._cat_tree_on_sel_changed, self.cat_tree)
+        self.Bind(wx.EVT_BUTTON, self._btn_edit_on_click, id=wx.ID_EDIT)
+        self.Bind(wx.EVT_BUTTON, self._btn_add_on_click, id=wx.ID_ADD)
+        self.Bind(wx.EVT_BUTTON, self._btn_del_on_click, id=wx.ID_DELETE)
+        self.Bind(wx.EVT_BUTTON, self._btn_close_on_click, id=wx.ID_CLOSE)
 
-    def _window_on_close(self, e):
-        self.cat_tree.destroy()
-        self.EndModal(wx.ID_CLOSE)
+    def _create_cat_tree(self):
+        self.cat_tree = CategoriesTree(self, self.db_error_handler)
+        self.cat_tree.SetMinSize((-1, 200))
+        return self.cat_tree
 
-    def _create_cat_tree(self, vbox):
-        cat_tree = CategoriesTree(self, self.db_error_handler)
-        cat_tree.SetMinSize((-1, 200))
-        self.Bind(wx.EVT_TREE_SEL_CHANGED, self._cat_tree_on_sel_changed,
-                  cat_tree)
-        vbox.Add(cat_tree, flag=wx.ALL|wx.EXPAND, border=BORDER)
-        return cat_tree
+    def _create_buttons(self):
+        sizer = wx.BoxSizer(wx.HORIZONTAL)
+        sizer.Add(self._create_edit_button(), flag=wx.RIGHT, border=BORDER)
+        sizer.Add(self._create_add_button(), flag=wx.RIGHT, border=BORDER)
+        sizer.Add(self._create_delete_button(), flag=wx.RIGHT, border=BORDER)
+        sizer.Add(self._create_close_button(), flag=wx.LEFT, border=BORDER)
+        self._enable_buttons(False)
+        return sizer
 
-    def _cat_tree_on_sel_changed(self, e):
-        self._updateButtons()
+    def _create_edit_button(self):
+        self.btn_edit = wx.Button(self, wx.ID_EDIT)
+        return self.btn_edit
 
-    def _create_buttons(self, vbox):
-        button_box = wx.BoxSizer(wx.HORIZONTAL)
-        self.btn_edit = self._create_edit_button(button_box)
-        self._create_add_button(button_box)
-        self.btn_del = self._create_delete_button(button_box)
-        self._create_close_button(button_box)
-        vbox.Add(button_box, flag=wx.ALL|wx.EXPAND, border=BORDER)
+    def _create_add_button(self):
+        return wx.Button(self, wx.ID_ADD)
 
-    def _create_edit_button(self, button_box):
-        btn = wx.Button(self, wx.ID_EDIT)
-        btn.Disable()
-        self.Bind(wx.EVT_BUTTON, self._btn_edit_on_click, btn)
-        button_box.Add(btn, flag=wx.RIGHT, border=BORDER)
-        return btn
+    def _create_delete_button(self):
+        self.btn_del = wx.Button(self, wx.ID_DELETE)
+        return self.btn_del
+
+    def _create_close_button(self):
+        return wx.Button(self, wx.ID_CLOSE)
+
+    def _enable_buttons(self, enabled):
+        self.btn_del.Enable(enabled)
+        self.btn_edit.Enable(enabled)
+        
+    def _updateButtons(self):
+        selected_category = self.cat_tree.get_selected_category() is not None
+        self._enable_buttons(selected_category)
 
     def _btn_edit_on_click(self, e):
         selected_category = self.cat_tree.get_selected_category()
@@ -104,35 +116,25 @@ class CategoriesEditor(wx.Dialog):
                           self.db_error_handler)
             self._updateButtons()
 
-    def _create_add_button(self, button_box):
-        btn = wx.Button(self, wx.ID_ADD)
-        self.Bind(wx.EVT_BUTTON, self._btn_add_on_click, btn)
-        button_box.Add(btn, flag=wx.RIGHT, border=BORDER)
-        return btn
-
     def _btn_add_on_click(self, e):
         add_category(self, self.db, self.db_error_handler)
         self._updateButtons()
 
-    def _create_delete_button(self, button_box):
-        btn = wx.Button(self, wx.ID_DELETE)
-        btn.Disable()
-        self.Bind(wx.EVT_BUTTON, self._btn_del_on_click, btn)
-        button_box.Add(btn, flag=wx.RIGHT, border=BORDER)
-        return btn
-
     def _btn_del_on_click(self, e):
         selected_category = self.cat_tree.get_selected_category()
         if selected_category is not None:
-            delete_category(self, self.db, selected_category,
-                            self.db_error_handler)
+            delete_category(self, self.db, selected_category, self.db_error_handler)
             self._updateButtons()
 
-    def _create_close_button(self, button_box):
-        btn = wx.Button(self, wx.ID_CLOSE)
-        self.Bind(wx.EVT_BUTTON, self._btn_close_on_click, btn)
-        button_box.Add(btn, flag=wx.LEFT, border=BORDER)
-        return btn
+    def _cat_tree_on_sel_changed(self, e):
+        self._updateButtons()
+
+    def _on_size(self, evt):
+        self.Layout()
+        
+    def _window_on_close(self, e):
+        self.cat_tree.destroy()
+        self.EndModal(wx.ID_CLOSE)
 
     def _btn_close_on_click(self, e):
         self.Close()
@@ -140,7 +142,3 @@ class CategoriesEditor(wx.Dialog):
     def db_error_handler(self, e):
         gui_utils.handle_db_error_in_dialog(self, e)
 
-    def _updateButtons(self):
-        selected_category = self.cat_tree.get_selected_category() is not None
-        self.btn_edit.Enable(selected_category)
-        self.btn_del.Enable(selected_category)
