@@ -63,15 +63,20 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 	def _on_table_mod(self, *args, **kwargs):
 		if kwargs['table'] != 'clin.export_item':
 			return
-		pat = gmPerson.gmCurrentPatient()
-		if not pat.connected:
-			return
-		if kwargs['pk_identity'] != pat.ID:
-			return
+		# work around problem in v21 change notification trigger on clin.export_item
+		# properly fixed in v22
+		if kwargs['pk_identity'] != -1:
+			pat = gmPerson.gmCurrentPatient()
+			if not pat.connected:
+				return
+			if kwargs['pk_identity'] != pat.ID:
+				return
 		self._schedule_data_reget()
+
 	#--------------------------------------------------------
 	def _on_list_item_selected(self, event):
 		event.Skip()
+
 	#--------------------------------------------------------
 	def _on_show_item_button_pressed(self, event):
 		event.Skip()
@@ -79,6 +84,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 		if item is None:
 			return
 		item.display_via_mime(block = False)
+
 	#--------------------------------------------------------
 	def _on_add_items_button_pressed(self, event):
 		event.Skip()
@@ -161,7 +167,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 
 		files2print = []
 		for item in items:
-			files2print.append(item.export_to_file())
+			files2print.append(item.save_to_file())
 
 		if len(files2print) == 0:
 			return
@@ -225,7 +231,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 				return True
 			if reuse_nonempty_dir is False:
 				path = gmTools.mk_sandbox_dir (
-					prefix = u'export-%s-' % gmPerson.gmCurrentPatient().dirname,
+					prefix = u'%s-' % gmPerson.gmCurrentPatient().dirname,
 					base_dir = path
 				)
 
@@ -339,7 +345,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 
 		files2mail = []
 		for item in items:
-			files2mail.append(item.export_to_file())
+			files2mail.append(item.save_to_file())
 
 		cmd = u'%s %s' % (external_cmd, u' '.join(files2mail))
 		if os.name == 'nt':
@@ -374,7 +380,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 
 		files2fax = []
 		for item in items:
-			files2fax.append(item.export_to_file())
+			files2fax.append(item.save_to_file())
 
 		fax_number = wx.GetTextFromUser (
 			_('Please enter the fax number here !\n\n'
@@ -447,12 +453,11 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 				tt = _('<gm-burn_doc(.bat) not found>')
 			self._BTN_burn_items.SetToolTipString(tt)
 
-		# make me and listctrl a file drop target
-		dt = gmGuiHelpers.cFileDropTarget(self)
+		# make me and listctrl file drop targets
+		dt = gmGuiHelpers.cFileDropTarget(target = self)
 		self.SetDropTarget(dt)
-		dt = gmGuiHelpers.cFileDropTarget(self._LCTRL_items)
+		dt = gmGuiHelpers.cFileDropTarget(on_drop_callback = self._drop_target_consume_filenames)
 		self._LCTRL_items.SetDropTarget(dt)
-		self._LCTRL_items.add_filenames = self.add_filenames_to_listctrl
 
 	#--------------------------------------------------------
 	def save_soap_note(self, soap=None):
@@ -469,10 +474,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 	#--------------------------------------------------------
 	# file drop target API
 	#--------------------------------------------------------
-	def add_filenames_to_listctrl(self, filenames):
-		self.add_filenames(filenames = filenames)
-	#--------------------------------------------------------
-	def add_filenames(self, filenames):
+	def _drop_target_consume_filenames(self, filenames):
 		pat = gmPerson.gmCurrentPatient()
 		if not pat.connected:
 			gmDispatcher.send(signal = 'statustext', msg = _('Cannot accept new documents. No active patient.'))
@@ -590,7 +592,7 @@ class cPrintMgrPluginPnl(wxgPrintMgrPluginPnl.wxgPrintMgrPluginPnl, gmRegetMixin
 
 		files2print = []
 		for printout in printouts:
-			files2print.append(printout.export_to_file())
+			files2print.append(printout.save_to_file())
 
 		if len(files2print) == 0:
 			return
