@@ -375,16 +375,28 @@ class cFileDropTarget(wx.FileDropTarget):
 		Widgets being declared file drop targets
 		must provide the method:
 
-			add_filenames(filenames)
+			def _drop_target_consume_filenames(self, filenames)
+
+		or declare a callback during __init__() of this class.
 	"""
 	#-----------------------------------------------
-	def __init__(self, target):
+	def __init__(self, target=None, on_drop_callback=None):
+		if target is not None:
+			try:
+				on_drop_callback = getattr(target, '_drop_target_consume_filenames')
+			except AttributeError:
+				_log.exception('[%s._drop_target_consume_filenames()] does not exist, cannot set as drop target callback', target)
+				raise
+		if not callable(on_drop_callback):
+			_log.error('[%s] not callable, cannot set as drop target callback', on_drop_callback)
+			raise AttributeError('[%s] not callable, cannot set as drop target callback', on_drop_callback)
+		self._on_drop_callback = on_drop_callback
 		wx.FileDropTarget.__init__(self)
-		self.target = target
-		_log.debug('setting up [%s] as file drop target', target)
+		_log.debug('setting up [%s] as file drop target', self._on_drop_callback)
+
 	#-----------------------------------------------
 	def OnDropFiles(self, x, y, filenames):
-		self.target.add_filenames(filenames)
+		self._on_drop_callback(filenames)
 
 # ========================================================================
 def file2scaled_image(filename=None, height=100):
