@@ -167,6 +167,7 @@ class cOrgUnitPhraseWheel(gmPhraseWheel.cPhraseWheel):
 		if self.GetData() is None:
 			return None
 		return gmOrganization.cOrgUnit(aPK_obj = self.GetData())
+
 #============================================================
 class cOrgUnitsManagerPnl(gmListWidgets.cGenericListManagerPnl):
 	"""A list for managing organizational units."""
@@ -408,7 +409,6 @@ class cOrgUnitAddressPnl(wxgOrgUnitAddressPnl.wxgOrgUnitAddressPnl):
 			self.message = _('<no unit selected>')
 			self._PRW_address_searcher.SetText(u'', None)
 			self._PRW_address_searcher.Enable(False)
-			self._PRW_address_searcher.display_as_disabled(True)
 			self._BTN_save_picked_address.Enable(False)
 			self._BTN_add_new_address.Enable(False)
 		else:
@@ -429,7 +429,6 @@ class cOrgUnitAddressPnl(wxgOrgUnitAddressPnl.wxgOrgUnitAddressPnl):
 			self._PRW_address_searcher.Enable(True)
 			self._PRW_address_searcher.address = self.__unit['pk_address']
 			self._PRW_address_searcher.Enable(True)
-			self._PRW_address_searcher.display_as_disabled(False)
 			self._BTN_save_picked_address.Enable(True)
 			self._BTN_add_new_address.Enable(True)
 	#--------------------------------------------------------
@@ -523,10 +522,10 @@ class cOrgUnitIDsMgrPnl(gmListWidgets.cGenericListManagerPnl):
 
 		gmListWidgets.cGenericListManagerPnl.__init__(self, *args, **kwargs)
 
+		self.refresh_callback = self.refresh
 		self.new_callback = self._add_id
 		self.edit_callback = self._edit_id
 		self.delete_callback = self._del_id
-		self.refresh_callback = self.refresh
 
 		self.__init_ui()
 		self.refresh()
