@@ -47,7 +47,6 @@ from Gnumed.wxpython import gmGuiHelpers
 from Gnumed.wxpython import gmAuthWidgets
 from Gnumed.wxpython import gmRegetMixin
 from Gnumed.wxpython import gmEditArea
-from Gnumed.wxpython import gmPhraseWheel
 from Gnumed.wxpython.gmPersonCreationWidgets import create_new_person
 
 
@@ -62,6 +61,7 @@ ID_BTN_AddNew = wx.NewId()
 def merge_patients(parent=None):
 	dlg = cMergePatientsDlg(parent, -1)
 	result = dlg.ShowModal()
+
 #============================================================
 from Gnumed.wxGladeWidgets import wxgMergePatientsDlg
 
@@ -191,20 +191,21 @@ class cSelectPersonFromListDlg(wxgSelectPersonFromListDlg.wxgSelectPersonFromLis
 		wxgSelectPersonFromListDlg.wxgSelectPersonFromListDlg.__init__(self, *args, **kwargs)
 
 		self.__cols = [
-			_('Title'),
 			_('Lastname'),
 			_('Firstname'),
-			_('Nickname'),
 			_('DOB'),
-			_('Gender'),
+			u'%s%s' % (gmTools.u_female, gmTools.u_male),
 			_('last visit'),
+			_('Nickname / Comment'),
 			_('found via')
 		]
 		self.__init_ui()
+
 	#--------------------------------------------------------
 	def __init_ui(self):
 		for col in range(len(self.__cols)):
 			self._LCTRL_persons.InsertColumn(col, self.__cols[col])
+
 	#--------------------------------------------------------
 	def set_persons(self, persons=None):
 		self._LCTRL_persons.DeleteAllItems()
@@ -214,32 +215,40 @@ class cSelectPersonFromListDlg(wxgSelectPersonFromListDlg.wxgSelectPersonFromLis
 			return False
 
 		for person in persons:
-			row_num = self._LCTRL_persons.InsertStringItem(pos, label = gmTools.coalesce(person['title'], ''))
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 1, label = person['lastnames'])
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 2, label = person['firstnames'])
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 3, label = gmTools.coalesce(person['preferred'], ''))
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 4, label = person.get_formatted_dob(format = '%Y %b %d', encoding = gmI18N.get_encoding()))
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 5, label = gmTools.coalesce(person['l10n_gender'], '?'))
+			row_num = self._LCTRL_persons.InsertStringItem(pos, label = gmTools.coalesce(person['title'], person['lastnames'], u'%s, %%s' % person['lastnames']))
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 1, label = person['firstnames'])
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 2, label = person.get_formatted_dob(format = '%Y %b %d', encoding = 'utf8'))
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 3, label = gmTools.coalesce(person['l10n_gender'], u'?'))
+
 			label = u''
 			if person.is_patient:
 				enc = person.get_last_encounter()
 				if enc is not None:
 					label = u'%s (%s)' % (gmDateTime.pydt_strftime(enc['started'], '%Y %b %d'), enc['l10n_type'])
-			self._LCTRL_persons.SetStringItem(index = row_num, col = 6, label = label)
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 4, label = label)
+
+			parts = []
+			if person['preferred'] is not None:
+				parts.append(person['preferred'])
+			if person['comment'] is not None:
+				parts.append(person['comment'])
+			self._LCTRL_persons.SetStringItem(index = row_num, col = 5, label = u' / '.join(parts))
+
 			try:
-				self._LCTRL_persons.SetStringItem(index = row_num, col = 7, label = person['match_type'])
+				self._LCTRL_persons.SetStringItem(index = row_num, col = 6, label = person['match_type'])
 			except KeyError:
 				_log.warning('cannot set match_type field')
-				self._LCTRL_persons.SetStringItem(index = row_num, col = 7, label = u'??')
+				self._LCTRL_persons.SetStringItem(index = row_num, col = 6, label = u'??')
 
 		for col in range(len(self.__cols)):
-			self._LCTRL_persons.SetColumnWidth(col=col, width=wx.LIST_AUTOSIZE)
+			self._LCTRL_persons.SetColumnWidth(col = col, width = wx.LIST_AUTOSIZE)
 
 		self._BTN_select.Enable(False)
 		self._LCTRL_persons.SetFocus()
 		self._LCTRL_persons.Select(0)
 
-		self._LCTRL_persons.set_data(data=persons)
+		self._LCTRL_persons.set_data(data = persons)
+
 	#--------------------------------------------------------
 	def get_selected_person(self):
 		return self._LCTRL_persons.get_item_data(self._LCTRL_persons.GetFirstSelected())
@@ -361,7 +370,7 @@ def load_persons_from_ca_msva():
 		try:
 			# FIXME: potentially return several persons per file
 			msva_dtos = gmCA_MSVA.read_persons_from_msva_file(filename = msva_file)
-		except StandardError:
+		except Exception:
 #			gmGuiHelpers.gm_show_error (
 #				_(
 #				'Cannot load patient from Medical Manager MSVA file\n\n'
@@ -834,6 +843,7 @@ def get_person_from_external_sources(parent=None, search_immediately=False, acti
 	dto.delete_from_source()
 
 	return ident
+
 #============================================================
 class cPersonSearchCtrl(wx.TextCtrl):
 	"""Widget for smart search for persons."""
@@ -903,7 +913,7 @@ class cPersonSearchCtrl(wx.TextCtrl):
 	#--------------------------------------------------------
 	def _remember_ident(self, ident=None):
 
-		if not isinstance(ident, gmPerson.cIdentity):
+		if not isinstance(ident, gmPerson.cPerson):
 			return False
 
 		# only unique identities
@@ -1100,6 +1110,7 @@ class cPersonSearchCtrl(wx.TextCtrl):
 		wx.EndBusyCursor()
 
 		return None
+
 #============================================================
 def _verify_staff_chart_access(patient=None):
 
@@ -1236,8 +1247,13 @@ def set_active_patient(patient=None, forced_reload=False):
 		return True
 
 	if isinstance(patient, gmPerson.cPatient):
-		pass
-	elif isinstance(patient, gmPerson.cIdentity):
+		if patient['is_deleted']:
+			_log.error('patient is disabled, will not use as active patient: %s', patient)
+			return False
+	elif isinstance(patient, gmPerson.cPerson):
+		if patient['is_deleted']:
+			_log.error('patient is disabled, will not use as active patient: %s', patient)
+			return False
 		patient = patient.as_patient
 	elif patient == -1:
 		pass
@@ -1245,7 +1261,7 @@ def set_active_patient(patient=None, forced_reload=False):
 		# maybe integer ?
 		success, pk = gmTools.input2int(initial = patient, minval = 1)
 		if not success:
-			raise ValueError('<patient> must be either -1, >0, or a cPatient, cIdentity or gmCurrentPatient instance, is: %s' % patient)
+			raise ValueError('<patient> must be either -1, >0, or a cPatient, cPerson or gmCurrentPatient instance, is: %s' % patient)
 		# but also valid patient ID ?
 		try:
 			patient = gmPerson.cPatient(aPK_obj = pk)
@@ -1459,7 +1475,6 @@ if __name__ == "__main__":
 #  Haywood, Ian <40
 #  ?, Ian 1977
 #  Ian Haywood, 19/12/77
-#  PUPIC
 # "hilb; karsten, 23.10.74"
 
 #------------------------------------------------------------
