@@ -76,7 +76,7 @@ def show_audit_trail(parent=None):
 				r['event_by'],
 				u'%s %s %s' % (
 					gmTools.coalesce(r['row_version_before'], gmTools.u_diameter),
-					gmTools.u_right_arrow,
+					gmTools.u_arrow2right,
 					gmTools.coalesce(r['row_version_after'], gmTools.u_diameter)
 				),
 				r['event_table'],
@@ -485,7 +485,7 @@ def set_active_praxis_branch(parent=None, no_parent=False):
 	#--------------------
 	branch = gmListWidgets.get_choices_from_list (
 		parent = parent,
-		msg = _("Select branch (of praxis [%s]) which you are logging in from.\n") % branches[0]['praxis'],
+		msg = _("Select the branch of praxis [%s] which you are logging in from.\n") % branches[0]['praxis'],
 		caption = _('Praxis branch selection ...'),
 		columns = [_('Branch'), _('Branch type')],
 		can_return_empty = False,
@@ -533,7 +533,6 @@ def manage_praxis_branches(parent=None):
 		_('Manage organizations and their units'),
 		manage_orgs
 	)
-	picker.allow_duplicate_picks = False
 	picker.left_item_tooltip_callback = get_unit_tooltip
 	picker.right_item_tooltip_callback = get_unit_tooltip
 	picker.set_columns(columns = [_('Units of "%s"') % praxis], columns_right = [_('Branches of your praxis')])
