@@ -120,6 +120,7 @@ class cProgressNoteInputNotebook(wx.Notebook, gmRegetMixin.cRegetOnPaintMixin):
 			style = wx.NB_TOP | wx.NB_MULTILINE | wx.NO_BORDER,
 			name = self.__class__.__name__
 		)
+		_log.debug('created wx.Notebook: %s with ID %s', self.__class__.__name__, self.Id)
 		gmRegetMixin.cRegetOnPaintMixin.__init__(self)
 		self.__pat = gmPerson.gmCurrentPatient()
 		self.__do_layout()
@@ -1234,7 +1235,7 @@ if __name__ == "__main__":
 #		app.SetWidget(cSingleBoxSOAPPanel, -1)
 #		app.MainLoop()
 
-	except StandardError:
+	except Exception:
 		_log.exception("unhandled exception caught !")
 		# but re-raise them
 		raise
