@@ -264,20 +264,22 @@ class cTopPnl(wxgTopPnl.wxgTopPnl):
 		now = gmDateTime.pydt_now_here()
 
 		# patient birthday ?
-		if self.curr_pat.get_formatted_dob(format = '%m-%d') == now.strftime('%m-%d'):
+		if self.curr_pat.get_formatted_dob(format = '%m-%d', honor_estimation = False) == now.strftime('%m-%d'):
 			template = _('%(sex)s  %(dob)s (%(age)s today !)')
 			tt += _("\nToday is the patient's birthday !\n\n")
 		else:
-			if self.curr_pat.current_birthday_passed():
+			if self.curr_pat.current_birthday_passed is True:
 				template = u'%(sex)s  %(dob)s%(l_arr)s (%(age)s)'
 				tt += _(u'Birthday: %s ago\n') % gmDateTime.format_apparent_age_medically (
 					age = gmDateTime.calculate_apparent_age(start = self.curr_pat.birthday_this_year, end = now)
 				)
-			else:
+			elif self.curr_pat.current_birthday_passed is False:
 				template = u'%(sex)s  %(r_arr)s%(dob)s (%(age)s)'
 				tt += _(u'Birthday: in %s\n') % gmDateTime.format_apparent_age_medically (
 					age = gmDateTime.calculate_apparent_age(start = now, end = self.curr_pat.birthday_this_year)
 				)
+			else:	# None, unknown
+				template = u'%(sex)s  %(dob)s (%(age)s)'
 
 		tt += _('Age: %s\n') % self.curr_pat['medical_age']
 
