@@ -18,6 +18,7 @@ from Gnumed.wxpython import gmAccessPermissionWidgets
 _log = logging.getLogger('gm.ui')
 #================================================================
 class gmEMRTimelinePlugin(gmPlugin.cNotebookPlugin):
+
 	tab_name = _("EMR Timeline")
 	required_minimum_role = 'full clinical access'
 
@@ -38,7 +39,7 @@ class gmEMRTimelinePlugin(gmPlugin.cNotebookPlugin):
 		return self._widget
 	#--------------------------------------------------------
 	def MenuInfo (self):
-		return ('emr', _('Show &Timeline'))
+		return ('emr', _('EMR &Timeline'))
 	#--------------------------------------------------------
 	def can_receive_focus(self):
 		if not self._verify_patient_avail():
@@ -93,7 +94,7 @@ if __name__ == '__main__':
 				patient.cleanup()
 			except:
 				print "error cleaning up patient"
-	except StandardError:
+	except Exception:
 		_log.exception("unhandled exception caught !")
 		# but re-raise them
 		raise
